==> oci-2.5.1.tar.gz: oci-2.5.1/src/oci/core/models/update_boot_volume_kms_key_details.py <==
# coding: utf-8
# Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateBootVolumeKmsKeyDetails(object):
    """
    UpdateBootVolumeKmsKeyDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateBootVolumeKmsKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kms_key_id:
            The value to assign to the kms_key_id property of this UpdateBootVolumeKmsKeyDetails.
        :type kms_key_id: str

        """
        self.swagger_types = {
            'kms_key_id': 'str'
        }

        self.attribute_map = {
            'kms_key_id': 'kmsKeyId'
        }

        self._kms_key_id = None

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        The OCID of the new KMS key which will be used to protect the specified volume.
        This key has to be a valid KMS key OCID, and the user must have key delegation policy to allow them to access this key.
        Even if the new KMS key is the same as the previous KMS key ID, the Block Volume service will use it to regenerate a new volume encryption key.


        :return: The kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        The OCID of the new KMS key which will be used to protect the specified volume.
        This key has to be a valid KMS key OCID, and the user must have key delegation policy to allow them to access this key.
        Even if the new KMS key is the same as the previous KMS key ID, the Block Volume service will use it to regenerate a new volume encryption key.


        :param kms_key_id: The kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        :type: str
        """
        self._kms_key_id = kms_key_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other

==> oci-2.12.4.tar.gz: oci-2.12.4/src/oci/core/models/update_boot_volume_kms_key_details.py <==
# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateBootVolumeKmsKeyDetails(object):
    """
    UpdateBootVolumeKmsKeyDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateBootVolumeKmsKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kms_key_id:
            The value to assign to the kms_key_id property of this UpdateBootVolumeKmsKeyDetails.
        :type kms_key_id: str

        """
        self.swagger_types = {
            'kms_key_id': 'str'
        }

        self.attribute_map = {
            'kms_key_id': 'kmsKeyId'
        }

        self._kms_key_id = None

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        The OCID of the new Key Management key to assign to protect the specified volume.
        This key has to be a valid Key Management key, and policies must exist to allow the user and the Block Volume service to access this key.
        If you specify the same OCID as the previous key's OCID, the Block Volume service will use it to regenerate a volume encryption key.


        :return: The kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        The OCID of the new Key Management key to assign to protect the specified volume.
        This key has to be a valid Key Management key, and policies must exist to allow the user and the Block Volume service to access this key.
        If you specify the same OCID as the previous key's OCID, the Block Volume service will use it to regenerate a volume encryption key.


        :param kms_key_id: The kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        :type: str
        """
        self._kms_key_id = kms_key_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
